@@ -9,7 +9,7 @@ use JSON::PP qw( encode_json );
 use Encode qw( encode_utf8 );
 
 # ABSTRACT: Dist::Zilla initialization tasks for Plicease
-our $VERSION = '1.75'; # VERSION
+our $VERSION = '1.76'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterMint';
@@ -76,6 +76,7 @@ sub gather_files
   $self->gather_file_changes($arg);
   $self->gather_files_tests($arg);
   $self->gather_file_gitignore($arg);
+  $self->gather_file_gitattributes($arg);
   $self->gather_file_travis_yml($arg);
 }
 
@@ -226,6 +227,20 @@ sub gather_file_gitignore
   $self->add_file($file);
 }
 
+sub gather_file_gitattributes
+{
+  my($self, $arg) = @_;
+  
+  my $name = $self->zilla->name;
+  
+  my $file = Dist::Zilla::File::InMemory->new({
+    name    => '.gitattributes',
+    content => "*.t linguist-language=Perl\n*.h linguist-language=C\n",
+  });
+  
+  $self->add_file($file);
+}
+
 has github_login => (
   is      => 'ro',
   isa     => 'Str',
@@ -312,7 +327,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 1.75
+version 1.76
 
 =head1 DESCRIPTION
 
